@@ -25,7 +25,6 @@ from ucitests import (
     fixtures,
     loaders,
     matchers,
-    tests,
 )
 
 
@@ -115,7 +114,7 @@ class TestPackagePathFromName(unittest.TestCase):
         self.loader = loaders.Loader(root=self.uniq_dir)
 
     def test_simple_package_name(self):
-        tests.write_tree_from_desc('''\
+        fixtures.build_tree('''\
 dir: foo
 file: foo/__init__.py
 imported = True
@@ -126,7 +125,7 @@ imported = True
         self.assertTrue(sys.modules['foo'].imported)
 
     def test_dotted_package_name(self):
-        tests.write_tree_from_desc('''\
+        fixtures.build_tree('''\
 dir: foo
 file: foo/__init__.py
 dir: foo/bar
@@ -247,7 +246,7 @@ class TestLoadTestsFromFile(unittest.TestCase):
         pass
 
     def test_single_test(self):
-        tests.write_tree_from_desc('''file: test_foo.py
+        fixtures.build_tree('''file: test_foo.py
 import unittest
 
 class Test(unittest.TestCase):
@@ -259,7 +258,7 @@ class Test(unittest.TestCase):
         self.assertEqual(1, suite.countTestCases())
 
     def test_sorted_tests(self):
-        tests.write_tree_from_desc('''file: test_foo.py
+        fixtures.build_tree('''file: test_foo.py
 import unittest
 
 class TestB(unittest.TestCase):
@@ -296,7 +295,7 @@ class TestLoadTestFromFiles(unittest.TestCase):
         self.loader = loaders.Loader()
 
     def test_empty_list(self):
-        tests.write_tree_from_desc('''file: p.py
+        fixtures.build_tree('''file: p.py
 import unittest
 
 class Test(unittest.TestCase):
@@ -307,7 +306,7 @@ class Test(unittest.TestCase):
         assertTestsEqual(self, [], self.loader.loadTestsFromFiles('.', []))
 
     def test_single_file(self):
-        tests.write_tree_from_desc('''file: test.py
+        fixtures.build_tree('''file: test.py
 import unittest
 
 class Test(unittest.TestCase):
@@ -319,7 +318,7 @@ class Test(unittest.TestCase):
                       self.loader.loadTestsFromFiles('.', ['test.py']))
 
     def test_several_files(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: test2.py
 import unittest
 
@@ -353,7 +352,7 @@ class TestLoadTestFromFiles_Matching(unittest.TestCase):
         # smaller tests. Cons: shared resource, do not abuse. Specific test are
         # encouraged to enrich locally to suit their needs rather than pollute
         # the shared env.
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: other.py
 import unittest
 class T(unittest.TestCase):
@@ -455,13 +454,13 @@ class TestLoadTestsFromPackage(unittest.TestCase):
         self.assertEqual(None, self.loader.loadTestsFromPackage('.'))
 
     def test_no_init_file(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 ''')
         self.assertEqual(None, self.loader.loadTestsFromPackage('t'))
 
     def test_import_failure(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 import not_a_python_package
@@ -470,7 +469,7 @@ import not_a_python_package
             self.loader.loadTestsFromPackage('t')
 
     def test_syntax_error(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 Do I look like python code ?
@@ -479,13 +478,13 @@ Do I look like python code ?
             self.loader.loadTestsFromPackage('t')
 
     def test_empty_package(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py''')
         assertTestIDs(self, [], self.loader.loadTestsFromPackage('t'))
 
     def test_init_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 import unittest
@@ -496,7 +495,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromPackage('t'))
 
     def test_file_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 file: t/test.py
@@ -508,7 +507,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromPackage('t'))
 
     def test_only_init_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
@@ -528,7 +527,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromPackage('t'))
 
     def test_init_and_file_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 import unittest
@@ -543,7 +542,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromPackage('t'))
 
     def test_none_from_load_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
@@ -560,7 +559,7 @@ class T(unittest.TestCase):
         self.assertEqual(None, self.loader.loadTestsFromPackage('t'))
 
     def test_load_tests_overrides(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
@@ -588,7 +587,7 @@ class TestLoadTestsFromTree(unittest.TestCase):
         fixtures.setup_for_local_imports(self)
         self.loader = loaders.Loader()
         # A common base for tests to build upon
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 file: t/ignored.py
@@ -602,11 +601,11 @@ class T(unittest.TestCase):
 ''')
 
     def test_empty(self):
-        tests.write_tree_from_desc('''dir: empty''')
+        fixtures.build_tree('''dir: empty''')
         assertTestIDs(self, [], self.loader.loadTestsFromTree('empty'))
 
     def test_none_from_load_tests(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
     return None
@@ -620,7 +619,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromTree('.'))
 
     def test_load_tests_explicit_file(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
     return loader.loadTestsFromFiles('t', ['test.py'])
@@ -632,7 +631,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromTree('.'))
 
     def test_load_tests_explicit_dir(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: t/__init__.py
 def load_tests(loader, std_tests, pattern):
     return loader.loadTestsFromFiles('t/sub', ['test.py'])
@@ -658,7 +657,7 @@ class TestSubLoader(unittest.TestCase):
         fixtures.setup_for_local_imports(self)
         self.loader = loaders.Loader()
         # A common base for tests to build upon
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t
 file: t/__init__.py
 file: t/ignored.py
@@ -672,7 +671,7 @@ class T(unittest.TestCase):
 ''')
 
     def test_load_tests_new_matching_files(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: t/__init__.py
 import os
 from ucitests import loaders, matchers
@@ -690,7 +689,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromTree('.'))
 
     def test_load_tests_new_matching_dirs(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 file: t/__init__.py
 import os
 from ucitests import loaders, matchers
@@ -717,7 +716,7 @@ class T(unittest.TestCase):
                       self.loader.loadTestsFromTree('.'))
 
     def test_load_single_test_dir_in_a_root(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t/t1
 file: t/t1/__init__.py
 file: t/t1/test.py
@@ -738,7 +737,7 @@ class T(unittest.TestCase):
                       subloader.loadTestsFromPackage('t1'))
 
     def test_load_from_sys_path_module(self):
-        tests.write_tree_from_desc('''
+        fixtures.build_tree('''
 dir: t/t1
 file: t/t1/__init__.py
 file: t/t1/test.py
